@@ -222,10 +222,10 @@ class Base(Controller):
     def sftp(self):
         ip = self.app.pargs.ip
         remote = self.app.pargs.__dict__.get('remote') or self.app.pargs.__dict__.get('r') or '/data/openpilot'
-        port = self.app.pargs.__dict__.get('port') or self.app.pargs.__dict__.get('p') or 22
+        port = self.app.pargs.__dict__.get('port') or self.app.pargs.__dict__.get('p') or 8022
         user = self.app.pargs.__dict__.get('user') or self.app.pargs.__dict__.get('u') or 'comma'
         server_name = self.app.pargs.__dict__.get('server_name') or self.app.pargs.__dict__.get('sn') or 'C3'
-        identity = self.app.pargs.__dict__.get('identity') or self.app.pargs.__dict__.get('i') or os.path.expanduser("~/.ssh/id_rsa")
+        identity = self.app.pargs.__dict__.get('identity') or self.app.pargs.__dict__.get('i') or os.path.expanduser("~/openpilot/tools/ssh/CL-key")
 
         from ..ext.sftp_conf import write_sftp
         
@@ -416,22 +416,41 @@ class Base(Controller):
         help='Operations with s3 bucket creationlabs-raw-data',
         arguments=[
             (['action'],{
-                "help" : "One of {ls, rm, cp, mv, download, upload}",
+                "help" : "One of {ls, link, lsa}",
                 "action" : "store"
             }),
             (['target'],{
-                "help" : "The target of the action. Can be a file or a directory",
+                "help" : "The target of the action. Can be {dongle_id, -1}",
                 "action" : "store"
+            }),
+            (['--num_segments'],{
+                "help" : "Number of recent files to show",
+                "action" : "store",
+                "default" : 10
+            }),
+            (['-n','--show_n'],{
+                "help" : "Number of recent files to show",
+                "action" : "store",
+                "default" : 25
             })
         ]
     )
     def s3(self):
-        if self.app.pargs.action == '-1':
+        if self.app.pargs.action == 'link':
             from ..ext.aws_s3 import get_lastest_file
             print(get_lastest_file(self.app.pargs.target))
+
+        # ls actions for all dongle ids
         if self.app.pargs.action == 'ls':
-            from ..ext.aws_s3 import get_latest_bucket
-            get_latest_bucket(self.app.pargs.target)
+            
+            from ..ext.aws_s3 import get_drives
+            show_n = int(self.app.pargs.__dict__.get('show_n') or self.app.pargs.__dict__.get('n'))
+
+            if self.app.pargs.target == '-1':
+                get_drives(self.app.pargs.target, show_n=show_n)
+            else:
+                num_segments = self.app.pargs.__dict__.get('n') or self.app.pargs.__dict__.get('num_segments')
+                get_drives(self.app.pargs.target, show_n=show_n, num_segments = num_segments)
 
     @ex(
         help='Operations on the SSH config',
