@@ -1,6 +1,8 @@
 '''
 Operations to speed up S3 access.
 '''
+import pandas as pd
+
 
 def get_lastest_file(dongle_id: str):
     """
@@ -8,26 +10,27 @@ def get_lastest_file(dongle_id: str):
     TODO: eventually paratemrize the -1 to get any file
     """
     import boto3
-    import pandas as pd
 
-    s3 = boto3.resource('s3')
+    s3_resource = boto3.resource('s3')
     bucket_name = 'creationlabs-raw-data'
-    bucket = s3.Bucket(bucket_name)
+    bucket = s3_resource.Bucket(bucket_name)
 
-    last_segment, last_complete_drive = get_latest_drives(s3, bucket_name, dongle_id)
-    # last_segment = '/'.join(last_file['Key'].split('/')[:-1])
+    last_segment, last_complete_drive = get_selected_drives(None, s3_resource, bucket_name, dongle_id, 10)
     # 064b1a99381ec054 2021-09-09--16-31-00 
     drive = '--'.join(last_segment.drive.split('--')[:-1])
     ret = f"http://cl-cabana.eba-eez4uaij.eu-west-1.elasticbeanstalk.com/cabana/?route={last_segment.dongle_id}%7C{drive}"
     return ret
 
-def get_latest_drives(s3_resource, bucket_name, dongle_id: str):
+def get_drives_df(s3_resource, bucket_name, dongle_id: str):
+    '''
+    TODO: this probably requires a significant refactoring.
+    '''
     from dt.ext.aws_s3_list import s3list
-    import pandas as pd
 
     bucket = s3_resource.Bucket(bucket_name)
     bucket_list = list(s3list(bucket, dongle_id, recursive=False, list_dirs=True))
     df = pd.DataFrame(bucket_list) 
+
     # filter out files with boot crash or swaglog
     df = df[~df.key.str[-5:-1].isin(['glog','boot','rash'])]
 
@@ -41,42 +44,54 @@ def get_latest_drives(s3_resource, bucket_name, dongle_id: str):
     df = df.sort_values(by=['date','time'], ascending=False)
     df.seg_num = pd.to_numeric(df.seg_num, errors='coerce')
     
+    return df
+
+def get_selected_drives(s3, s3_resource, bucket_name, dongle_id, show_n):
+    df = get_drives_df(s3_resource, bucket_name, dongle_id)
     latest_drive = df.iloc[0]
-    if len(df) > 1:
-        last_complete_drive = df[df.seg_num!=0].iloc[0]
+    last_complete_drives = df[df.seg_num!=0]
+
+    if len(last_complete_drives) > 0:
+        last_complete_drive = last_complete_drives.iloc[0]
     else:
         last_complete_drive = latest_drive
 
     return latest_drive, last_complete_drive
 
-    
+def get_dongle_drives(s3, s3_resource, bucket_name, dongle_id: str, show_n: int):
+    from tqdm import tqdm 
 
-def get_latest_bucket(target, bucket_name: str = 'creationlabs-raw-data', show_n: int = 25):
-    # TODO: profile
-    # get all dongle ids
-    import boto3 
-    import pandas as pd
-    import humanize
-
-    pd.set_option('display.max_colwidth',70)
-    
-    s3 = boto3.resource('s3')
-    s3_resource = boto3.session.Session(region_name='eu-west-1').client('s3')
-
-
-    raw_data_buckets = s3_resource.list_objects_v2(Bucket='creationlabs-raw-data',Delimiter='/')
+    raw_data_buckets = s3.list_objects_v2(Bucket='creationlabs-raw-data',Delimiter='/')
     dongle_ids = [x['Prefix'].split('/')[0] for x in raw_data_buckets['CommonPrefixes']]
 
     latest_files = []
 
-    for did in dongle_ids:
-        latest_drive, last_complete_drive = get_latest_drives(s3, bucket_name, did)
+    for did in tqdm(sorted(dongle_ids[:show_n])):
+        latest_drive, last_complete_drive = get_selected_drives(s3, s3_resource, bucket_name, did, show_n)
         latest_files.append(latest_drive)
         latest_files.append(last_complete_drive)
 
     df = pd.DataFrame(latest_files).reset_index()
+    return df
+    
+
+def get_drives(target, bucket_name: str = 'creationlabs-raw-data', 
+                        show_n: int = 25, num_segments: int = 1):
+    # TODO: profile
+    # get all dongle ids
+    import boto3 
+    import humanize
+
+    pd.set_option('display.max_colwidth',70)
+    
+    s3 = boto3.session.Session(region_name='eu-west-1').client('s3')
+    s3_resource = boto3.resource('s3')
+
+    if target=='-1':
+        df = get_dongle_drives(s3, s3_resource, bucket_name, target, show_n)
+    else:
+        df = get_drives_df(s3_resource, bucket_name, dongle_id=target)
 
-    # df['upload_time'] =  df.file.str.split('/').str[-1].str.split('--').str[0:2].str.join('--')
     df['upload_time'] = df.drive.str.split('--').str[:-1].str.join('--')
 
     # TODO: fix this
